import React from 'react'
import PropTypes from 'prop-types'
import { ThemeContext, defaultTheme } from '../utils'
import 'reset-css'

/**
 * Set base styles for an entire application.
 * 
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const Base = ({
    theme = defaultTheme,
    style,
    children
}) => (
    <ThemeContext.Provider value={theme}>
        <div
            style={{
                minHeight: '100vh',
                color: theme.neutral[theme.neutral.length - 1],
                background: theme.neutral[1],
                ...style
            }}
        >
            {children}
        </div>
    </ThemeContext.Provider>
)

Base.propTypes = {
    theme: PropTypes.object,
    style: PropTypes.object,
    children: PropTypes.node
}

export default Base