import React, { useContext, useState } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils/index.js'

/**
 * ...
 * 
 * @param  {string} props.label    - ...
 * @param  {number} props.value    - ...
 * @param  {string} props.units    - ...
 * @param  {number} props.warning  - ...
 * @param  {number} props.error    - ...
 * @param  {number} props.max      - ...
 * @param  {object} props.style    - ...
 * @param  {object} props.children - ...
 * @return {object}                - React markup
 */
const Diagnostic = ({
    label = 'Unknown',
    value,
    units = '',
    warning,
    error,
    max,
    style,
    children
}) => {
    const [hovering, setHovering] = useState(false)
    const {indicators, neutral} = useContext(ThemeContext)
    const threshold = value >= error ? 'error' : value >= warning ? 'warning' : 'success'
    const color = indicators[threshold]
    const hoveringStyle = !hovering ? {} : {
        position: 'relative',
        padding: 10,
        marginLeft: -20,
        left: 10,
        borderRadius: 10,
        boxShadow: `0 0 25px ${neutral[2]}`,
        background: neutral[0]
    }

    return (
        <section
            onMouseOver={() => setHovering(true)}
            onMouseOut={() => setHovering(false)}
            style={{
                width: 220,
                marginTop: 16,
                fontSize: 12.8,
                ...hoveringStyle,
                ...style
            }}
        >
            <div
                style={{
                    display: 'flex',
                    marginBottom: 8
                }}
            >
                <span
                    style={{
                        fontWeight: 700,
                        color
                    }}
                >
                    {value + units}
                </span>
                <span
                    style={{
                        margin: '0 12px',
                        color: neutral[2]
                    }}
                >
                    /
                </span>
                <span>
                    {label}
                </span>
            </div>
            <figure
                style={{
                    height: 6,
                    borderRadius: 6,
                    boxShadow: hovering ? null : `0 0 8px ${neutral[2]}`,
                    background: hovering ? neutral[1] : neutral[0],
                    overflow: 'hidden'
                }}
            >
                <figure
                    style={{
                        width: `${(value / Math.max(max, value)) * 100}%`,
                        height: '100%',
                        borderRadius: 6,
                        background: color
                    }}
                />
            </figure>
            {hovering && (
                <div
                    style={{
                        marginTop: 6,
                        lineHeight: 1.4,
                        pointerEvents: 'none'
                    }}
                >
                    {children}
                </div>
            )}
        </section>
    )
}

Diagnostic.propTypes = {
    label: PropTypes.node,
    value: PropTypes.number,
    units: PropTypes.string,
    warning: PropTypes.number,
    error: PropTypes.number,
    max: PropTypes.number,
    style: PropTypes.object,
    children: PropTypes.node
}

export default Diagnostic