import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a customizable key and value.
 * 
 * @param  {object} props.label    - Describes what the value represents
 * @param  {object} props.children - A value that corresponds to the given `label`
 * @return {object}                - React markup
 */
const Field = ({
    label,
    style,
    children
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <div
            style={{
                display: 'flex',
                marginTop: 6,
                lineHeight: 1.4,
                fontSize: 12.8,
                ...style
            }}
        >
            <dt
                style={{
                    flex: `0 0 72px`,
                    color: neutral[neutral.length - 3]
                }}
            >
                {label}:
            </dt>
            <dd
                style={{
                    flex: '1 1 auto',
                    overflow: 'hidden'
                }}
            >
                {children}
            </dd>
        </div>
    )
}

Field.propTypes = {
    label: PropTypes.string,
    children: PropTypes.node
}

export default Field