import React, { useState, useEffect } from 'react'
import PropTypes from 'prop-types'

/**
 * Display a deferred background image. Useful to prevent layout thrashing in
 * scenarios where you may be re-rendering extremely quickly (e.g. when typing
 * or scrolling).
 * 
 * @param  {string} props.element - ...
 * @param  {string} props.src     - ...
 * @param  {number} props.delay   - ...
 * @return {object}               - ...
 */
const Image = ({
    element: Element = 'div',
    src,
    delay = 500,
    ...props
}) => {
    const [url, setURL] = useState(null)

    useEffect(() => {
        const timeout = setTimeout(() => {
            setURL(src)
        }, delay)

        return () => clearTimeout(timeout)
    }, [ src ])

    return (
        <Element
            {...props}
            style={{
                backgroundImage: url && `url("${url}")`,
                ...props.style
            }}
        />
    )
}

Image.propTypes = {
    element: PropTypes.string,
    src: PropTypes.string,
    delay: PropTypes.number
}

export default Image