import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import Action from './action.jsx'
import { ThemeContext } from '../utils'

/**
 * Display a set of `options` of which only one can be chosen at once.
 * 
 * @param  {string}   props.selected - Selected option `value`
 * @param  {array}    props.options  - A list of option objects
 * @param  {function} props.onClick  - A callback fired on click
 * @return {object}                  - React markup
 */
const Selector = ({
    selected,
    options,
    onClick
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <Action
            element="select"
            value={selected || ''}
            onChange={e => onClick(options.find(option => option.value === e.target.value), e)}
            style={{
                fontSize: 16,
                color: neutral[neutral.length - 2],
                appearance: 'none'
            }}
        >
            {options.map(option => (
                <option
                    key={option.value}
                    value={option.value}
                >
                    {option.label}
                </option>
            ))}
        </Action>
    )
}

Selector.propTypes = {
    selected: PropTypes.string,
    options: PropTypes.arrayOf(
        PropTypes.shape({
            label: PropTypes.string.isRequired,
            value: PropTypes.string.isRequired
        })
    ).isRequired,
    onClick: PropTypes.func
}

export default Selector