import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a subtitle, typically paired with a `<Title />`.
 * 
 * @param  {object} props.style    - Override or add any additional styles
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const Subtitle = ({
    style,
    children,
    ...props
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <h3
            {...props}
            style={{
                marginTop: 6,
                fontSize: 14,
                color: neutral[3],
                ...style
            }}
        >
            {children}
        </h3>
    )
}

Subtitle.propTypes = {
    style: PropTypes.object,
    children: PropTypes.node
}

export default Subtitle