import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a full width section and title. Typically, a few of these are used
 * to display high-level summaries of the data within a product.
 * 
 * @param  {string}  props.title     - Concise title for the summary
 * @param  {boolean} props.detail    - More details about the summary (left panel)
 * @param  {number}  props.margin    - Left gutter for title
 * @param  {boolean} props.border    - Display bottom border
 * @param  {object}  props.children  - Any valid react children
 * @return {object}                  - React markup
 */
const Summary = ({
    title = 'Untitled',
    detail,
    margin = 24,
    border = true,
    children
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <React.Fragment>
            <div
                style={{
                    display: 'flex',
                    padding: '60px 0',
                    boxSizing: 'border-box',
                    flexDirection: detail ? 'row' : 'column'
                }}
            >
                <div
                    style={{
                        flex: detail ? '0 0 272px' : '0 0 auto',
                        paddingLeft: margin,
                        marginRight: 30
                    }}
                >
                    <h2
                        style={{
                            fontSize: 25,
                            fontWeight: 500,
                            paddingBottom: 12,
                            color: neutral[neutral.length - 1]
                        }}
                    >
                        { title }
                    </h2>
                    <div
                        style={{
                            fontSize: 12.8,
                            lineHeight: 1.5,
                            color: '#666666'
                        }}
                    >
                        { detail }
                    </div>
                </div>
                <div style={{ flex: '1 1 auto' }}>
                    { children }
                </div>
            </div>
            {border && (
                <figure
                    style={{
                        marginLeft: margin,
                        marginRight: margin,
                        height: 2,
                        background: '#E1E1E1'
                    }}
                />
            )}
        </React.Fragment>
    )
}

Summary.propTypes = {
    title: PropTypes.node,
    detail: PropTypes.node,
    margin: PropTypes.number,
    border: PropTypes.bool,
    children: PropTypes.node
}

export default Summary