import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '../utils'

/**
 * Display a set of tags (typically a list of strings).
 * 
 * @param  {array}    props.list    - A list of valid react nodes
 * @param  {object}   props.style   - Override or add any additional styles
 * @param  {function} props.onClick - Called on click of a tag
 * @return {object}                 - React markup
 */
const Tags = ({
    list,
    style,
    tagStyle,
    onClick
}) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <ul
            style={{
                display: 'flex',
                ...style
            }}
        >
            {list.map((item, i) => (
                <li
                    key={i}
                    style={{
                        marginRight: 8,
                        padding: 4,
                        fontSize: 10.24,
                        fontWeight: 500,
                        letterSpacing: 0.1,
                        borderRadius: 3,
                        whiteSpace: 'nowrap',
                        background: neutral[2],
                        ...tagStyle
                    }}
                    onClick={onClick}
                >
                    {item}
                </li>
            ))}
        </ul>
    )
}

Tags.propTypes = {
    list: PropTypes.arrayOf(PropTypes.node),
    style: PropTypes.object,
    onClick: PropTypes.func
}

export default Tags