import React from 'react'
import PropTypes from 'prop-types'

/**
 * Display a title, sometimes paired with a `<Subtitle />`.
 * 
 * @param  {object} props.style    - Override or add any additional styles
 * @param  {object} props.children - Any valid react children
 * @return {object}                - React markup
 */
const Title = ({
    style,
    children,
    ...props
}) => (
    <h2
        {...props}
        style={{
            fontSize: 20,
            fontWeight: 700,
            letterSpacing: 0.5,
            ...style
        }}
    >
        {children}
    </h2>
)

Title.propTypes = {
    style: PropTypes.object,
    children: PropTypes.node
}

export default Title