// Foundational
import React from 'react'

/**
 * Flatten react children
 * 
 * @param  {object} children - ...
 * @param  {array}  flat     - ...
 * @return {array}           - ...
 */
export const flatten = (children, flat = []) => {
    flat = [ ...flat, ...React.Children.toArray(children) ]

    if (children.props && children.props.children) {
        return flatten(children.props.children, flat)
    }

    return flat
}

/**
 * Simplify react children for comparison
 * 
 * @param  {object} children - ...
 * @return {array}           - ...
 */
export const simplify = children => {
    const flat = flatten(children)

    return flat.map(child => {
        if (typeof child !== 'string') {
            const {
                key,
                ref,
                type,
                props: {
                    children,
                    ...props
                }
            } = child

            return {
                key, ref, type, props
            }

        } else return child
    })
}