import { createContext, useContext, useEffect } from 'react'

/**
 * Preset dimensions for cards.
 * 
 * @type {object}
 */
export const presets = {
    small: { width: 243, height: 160 },
    medium: { width: 243, height: 360 },
    large: { width: 420, height: 260 }
}

/**
 * Default color scheme for any foundation application
 * 
 * @type {object}
 */
export const defaultTheme = {
    neutral: [ '#FFFFFF', '#F6F6F6', '#D8D8D8', '#9B9B9B', '#777777', '#333333' ],
    primary: [ '#5AC8FA', '#4A90E2' ],
    secondary: [ '#D0021B' ],
    indicators: {
        success: '#2ECC71',
        warning: '#F1C40F',
        error: '#E74C3C'
    }
}

/**
 * Context instance for color scheming. The format is just an initial concept,
 * based on a modified version of one of the naming ideas in the article below.
 * 
 * @see https://css-tricks.com/what-do-you-name-color-variables/
 * @type {object}
 */
export const ThemeContext = createContext(defaultTheme)

/**
 * Benchmarking hook to track things like the number of renders.
 *
 */
export const useBenchmark = () => {
    const {onRender} = useContext(BenchmarkContext)
    
    useEffect(onRender)
}

/**
 * Context instance for benchmarking. Combined with `useBenchmark`, this allows
 * us to peek inside components in the lab.
 *
 * @type {object}
 */
export const BenchmarkContext = createContext({})

/**
 * Default resizing algorithm
 * 
 * @param  {object} dimensions - ...
 * @return {object}            - ...
 */
export const resizeGridDefault = dimensions => {
    let gap = 16
    let cardWidth = presets.medium.width
    let cardHeight = presets.medium.height
    let availableColumns = Math.floor(dimensions.width / (cardWidth + 1.6 * gap))

    if (availableColumns < 2) {
        cardWidth = dimensions.width - (3 * gap)
        cardHeight = cardWidth / 1.618
    }

    return {
        columns: Math.min(availableColumns, 4),
        cardWidth,
        cardHeight
    }
}